==> naiveproxy-91.0.4472.77-1.tar.gz: naiveproxy-91.0.4472.77-1/src/net/android/network_library_stub.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "net/android/network_library.h"

namespace net {
namespace android {

void VerifyX509CertChain(const std::vector<std::string>& cert_chain,
                         base::StringPiece auth_type,
                         base::StringPiece host,
                         CertVerifyStatusAndroid* status,
                         bool* is_issued_by_known_root,
                         std::vector<std::string>* verified_chain) {
}

void AddTestRootCertificate(const uint8_t* cert, size_t len) {
}

void ClearTestRootCertificates() {
}

bool IsCleartextPermitted(const std::string& host) {
  return true;
}

bool HaveOnlyLoopbackAddresses() {
  return false;
}

bool GetMimeTypeFromExtension(const std::string& extension,
                              std::string* result) {
  return false;
}

std::string GetTelephonyNetworkOperator() {
  return {};
}

std::string GetTelephonySimOperator() {
  return {};
}

bool GetIsRoaming() {
  return false;
}

bool GetIsCaptivePortal() {
  return false;
}

std::string GetWifiSSID() {
  return {};
}

base::Optional<int32_t> GetWifiSignalLevel() {
  return {};
}

bool GetDnsServers(std::vector<IPEndPoint>* dns_servers,
                   bool* dns_over_tls_active,
                   std::string* dns_over_tls_hostname,
                   std::vector<std::string>* search_suffixes) {
  return false;
}

bool ReportBadDefaultNetwork() {
  return false;
}

void TagSocket(SocketDescriptor socket, uid_t uid, int32_t tag) {
}

}  // namespace android
}  // namespace net

==> naiveproxy-93.0.4577.63-1.tar.gz: naiveproxy-93.0.4577.63-1/src/net/android/network_library_stub.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "net/android/network_library.h"

namespace net {
namespace android {

void VerifyX509CertChain(const std::vector<std::string>& cert_chain,
                         base::StringPiece auth_type,
                         base::StringPiece host,
                         CertVerifyStatusAndroid* status,
                         bool* is_issued_by_known_root,
                         std::vector<std::string>* verified_chain) {
}

void AddTestRootCertificate(const uint8_t* cert, size_t len) {
}

void ClearTestRootCertificates() {
}

bool IsCleartextPermitted(const std::string& host) {
  return true;
}

bool HaveOnlyLoopbackAddresses() {
  return false;
}

bool GetMimeTypeFromExtension(const std::string& extension,
                              std::string* result) {
  return false;
}

std::string GetTelephonyNetworkOperator() {
  return {};
}

std::string GetTelephonySimOperator() {
  return {};
}

bool GetIsRoaming() {
  return false;
}

bool GetIsCaptivePortal() {
  return false;
}

std::string GetWifiSSID() {
  return {};
}

absl::optional<int32_t> GetWifiSignalLevel() {
  return {};
}

bool GetDnsServers(std::vector<IPEndPoint>* dns_servers,
                   bool* dns_over_tls_active,
                   std::string* dns_over_tls_hostname,
                   std::vector<std::string>* search_suffixes) {
  return false;
}

bool ReportBadDefaultNetwork() {
  return false;
}

void TagSocket(SocketDescriptor socket, uid_t uid, int32_t tag) {
}

}  // namespace android
}  // namespace net
